@@ -21,11 +21,11 @@
 #include <KAuthorized>
 #include <KLocalizedString>
 
-#if KF5ConfigWidgets_FOUND
+#if KFConfigWidgets_FOUND
 #include <KStandardAction>
 #endif
 
-#if defined KF5XmlGui_FOUND
+#if defined KFXmlGui_FOUND
 #include <KActionCollection>
 #include <KAboutApplicationDialog>
 #include <KHelpMenu>
@@ -36,7 +36,7 @@
 #include <KColorSchemeManager>
 #include <KAboutData>
 
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
 #include <KIO/OpenFileManagerWindowJob>
 #endif
 
@@ -63,14 +63,14 @@ class ElisaApplicationPrivate
 public:
 
     explicit ElisaApplicationPrivate(QObject *parent)
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
         : mCollection(parent)
 #endif
     {
         Q_UNUSED(parent)
     }
 
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
     KActionCollection mCollection;
 #endif
 
@@ -120,6 +120,11 @@ ElisaApplication::ElisaApplication(QObject *parent) : QObject(parent), d(std::ma
 ElisaApplication::~ElisaApplication()
 = default;
 
+KColorSchemeManager *ElisaApplication::getSchemes()
+{
+    return d->mSchemes;
+}
+
 QAbstractItemModel *ElisaApplication::colorSchemesModel()
 {
     return d->mSchemes->model();
@@ -132,7 +137,7 @@ void ElisaApplication::activateColorScheme(const QString &name)
 
 void ElisaApplication::setupActions(const QString &actionName)
 {
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
     if (actionName == QLatin1String("file_quit")) {
         auto quitAction = KStandardAction::quit(QCoreApplication::instance(), &QCoreApplication::quit, &d->mCollection);
         d->mCollection.addAction(actionName, quitAction);
@@ -281,7 +286,7 @@ void ElisaApplication::appHelpActivated()
 
 void ElisaApplication::aboutApplication()
 {
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
     static QPointer<QDialog> dialog;
     if (!dialog) {
         dialog = new KAboutApplicationDialog(KAboutData::applicationData(), nullptr);
@@ -293,7 +298,7 @@ void ElisaApplication::aboutApplication()
 
 void ElisaApplication::reportBug()
 {
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
     static QPointer<QDialog> dialog;
     if (!dialog) {
         dialog = new KBugReport(KAboutData::applicationData(), nullptr);
@@ -305,7 +310,7 @@ void ElisaApplication::reportBug()
 
 void ElisaApplication::configureShortcuts()
 {
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
     KShortcutsDialog dlg(KShortcutsEditor::ApplicationAction, KShortcutsEditor::LetterShortcutsAllowed, nullptr);
     dlg.setModal(true);
     dlg.addCollection(&d->mCollection);
@@ -359,6 +364,7 @@ void ElisaApplication::configChanged()
     Q_EMIT useFavoriteStyleRatingsChanged();
     Q_EMIT embeddedViewChanged();
     Q_EMIT initialViewIndexChanged();
+    Q_EMIT initialFilesViewPathChanged();
 }
 
 DataTypes::EntryDataList ElisaApplication::checkFileListAndMakeAbsolute(const DataTypes::EntryDataList &filesList,
@@ -472,6 +478,7 @@ void ElisaApplication::initializePlayer()
     QObject::connect(d->mAudioControl.get(), &ManageAudioPlayer::updateData, d->mMediaPlayList.get(), &MediaPlayList::setData);
 
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::ensurePlay, d->mAudioControl.get(), &ManageAudioPlayer::ensurePlay);
+    QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::requestPlay, d->mAudioControl.get(), &ManageAudioPlayer::requestPlay);
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::playListFinished, d->mAudioControl.get(), &ManageAudioPlayer::playListFinished);
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::currentTrackChanged, d->mAudioControl.get(), &ManageAudioPlayer::setCurrentTrack);
     QObject::connect(d->mMediaPlayListProxyModel.get(), &MediaPlayListProxyModel::clearPlayListPlayer, d->mAudioControl.get(), &ManageAudioPlayer::saveForUndoClearPlaylist);
@@ -511,7 +518,7 @@ void ElisaApplication::initializePlayer()
 
 QAction * ElisaApplication::action(const QString& name)
 {
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
     auto resultAction = d->mCollection.action(name);
 
     if (!resultAction) {
@@ -550,14 +557,10 @@ void ElisaApplication::installKeyEventFilter(QObject *object)
 bool ElisaApplication::eventFilter(QObject *object, QEvent *event)
 {
     Q_UNUSED(object)
-#if KF5XmlGui_FOUND
+#if KFXmlGui_FOUND
     auto *keyEvent = static_cast<QKeyEvent*>(event);
     auto playPauseAction = d->mCollection.action(QStringLiteral("Play-Pause"));
-#if QT_VERSION > QT_VERSION_CHECK(6, 0, 0)
     if (keyEvent->key() == Qt::Key_Space && playPauseAction->shortcut()[0].key() == Qt::Key_Space) {
-#else
-    if (keyEvent->key() == Qt::Key_Space && playPauseAction->shortcut()[0] == Qt::Key_Space) {
-#endif
         return true;
     }
 #else
@@ -568,7 +571,7 @@ bool ElisaApplication::eventFilter(QObject *object, QEvent *event)
 
 void ElisaApplication::showInFolder(QUrl filePath)
 {
-#if KF5KIO_FOUND
+#if KFKIO_FOUND
     KIO::highlightInFileManager({filePath});
 #else
     Q_UNUSED(filePath)
@@ -669,4 +672,10 @@ int ElisaApplication::initialViewIndex() const
     return result;
 }
 
+QString ElisaApplication::initialFilesViewPath() const
+{
+    return Elisa::ElisaConfiguration::initialFilesViewPath();
+}
+
+
 #include "moc_elisaapplication.cpp"
