@@ -15,11 +15,6 @@
 #include <QTimer>
 #include <QDateTime>
 
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#define PlaybackState State
-#define playbackState state
-#endif
-
 ManageAudioPlayer::ManageAudioPlayer(QObject *parent) : QObject(parent)
 {
 
@@ -347,6 +342,10 @@ void ManageAudioPlayer::ensurePlay()
     }
 }
 
+void ManageAudioPlayer::requestPlay() {
+    mPlayingState = true;
+}
+
 void ManageAudioPlayer::stop()
 {
     mPlayingState = false;
@@ -547,9 +546,9 @@ void ManageAudioPlayer::triggerStop()
     QTimer::singleShot(0, this, [this]() {Q_EMIT playerStop();});
 }
 
-void ManageAudioPlayer::triggerSkipNextTrack()
+void ManageAudioPlayer::triggerSkipNextTrack(ElisaUtils::SkipReason reason /*= SkipReason::Automatic */)
 {
-    QTimer::singleShot(0, this, [this]() {Q_EMIT skipNextTrack();});
+    QTimer::singleShot(0, this, [this, reason]() {Q_EMIT skipNextTrack(reason);});
 }
 
 void ManageAudioPlayer::restorePreviousState()
