@@ -10,7 +10,7 @@
 
 #include <KLocalizedString>
 
-#include <QtConcurrent>
+#include <QtConcurrentRun>
 
 #include <algorithm>
 
@@ -198,6 +198,8 @@ QVariant TrackMetadataModel::data(const QModelIndex &index, int role) const
         case DataTypes::IsDirectoryRole:
         case DataTypes::IsPlayListRole:
         case DataTypes::FilePathRole:
+        case DataTypes::HasChildrenRole:
+        case DataTypes::MultipleImageUrlsRole:
             break;
         }
         break;
@@ -324,8 +326,8 @@ void TrackMetadataModel::filterDataFromTrackData()
 
 void TrackMetadataModel::removeMetaData(DataTypes::ColumnsRoles metaData)
 {
-    auto itMetaData = std::find(mTrackKeys.begin(), mTrackKeys.end(), metaData);
-    if (itMetaData == mTrackKeys.end()) {
+    auto itMetaData = std::find(mTrackKeys.cbegin(), mTrackKeys.cend(), metaData);
+    if (itMetaData == mTrackKeys.cend()) {
         return;
     }
 
@@ -573,6 +575,8 @@ QString TrackMetadataModel::nameFromRole(DataTypes::ColumnsRoles role)
     case DataTypes::IsDirectoryRole:
     case DataTypes::IsPlayListRole:
     case DataTypes::FilePathRole:
+    case DataTypes::HasChildrenRole:
+    case DataTypes::MultipleImageUrlsRole:
         break;
     }
     return result;
