@@ -16,14 +16,15 @@
 
 #include <QUrl>
 #include <QDir>
+#include <QStandardPaths>
 
 class ViewsListDataPrivate
 {
 public:
-    QList<ViewParameters> mViewsParameters = {{{i18nc("Title of the view of the playlist", "Now Playing")},
+    QList<ViewParameters> mViewsParameters = {{{i18nc("@title:window Title of the view of the playlist", "Now Playing")},
                                                QUrl{QStringLiteral("image://icon/view-media-lyrics")},
                                                ViewManager::ContextView},
-                                              {{i18nc("Title of the view of recently played tracks", "Recently Played")},
+                                              {{i18nc("@title:window Title of the view of recently played tracks", "Recently Played")},
                                                QUrl{QStringLiteral("image://icon/media-playlist-play")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
@@ -31,29 +32,27 @@ public:
                                                ElisaUtils::Track,
                                                DataTypes::LastPlayDate,
                                                {DataTypes::LastPlayDate},
-                                               {i18n("Last Played Date")},
+                                               {i18nc("@title:menu", "Last Played Date")},
                                                Qt::DescendingOrder,
-                                               {i18n("Least Recently Played First"), i18n("Most Recently Played First")},
+                                               {i18nc("@item:inmenu", "Least Recently Played First"), i18nc("@item:inmenu", "Most Recently Played First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack,
-                                               ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of frequently played tracks", "Frequently Played")},
+                                               ViewManager::IsTrack},
+                                              {{i18nc("@title:window Title of the view of frequently played tracks", "Frequently Played")},
                                                QUrl{QStringLiteral("image://icon/view-media-playcount")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
                                                ElisaUtils::FilterByFrequentlyPlayed,
                                                ElisaUtils::Track,
-                                               DataTypes::PlayFrequency,
-                                               {DataTypes::PlayFrequency},
-                                               {i18n("Play Frequency")},
+                                               DataTypes::PlayCounter,
+                                               {DataTypes::PlayCounter},
+                                               {i18nc("@title:menu", "Play Frequency")},
                                                Qt::DescendingOrder,
-                                               {i18n("Least Frequently Played First"), i18n("Most Frequently Played First")},
+                                               {i18nc("@item:inmenu", "Least Frequently Played First"), i18nc("@item:inmenu", "Most Frequently Played First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack,
-                                               ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all albums", "Albums")},
+                                               ViewManager::IsTrack},
+                                              {{i18nc("@title:window Title of the view of all albums", "Albums")},
                                                QUrl{QStringLiteral("image://icon/view-media-album-cover")},
                                                ViewManager::GridView,
                                                ViewManager::GenericDataModel,
@@ -61,14 +60,13 @@ public:
                                                ElisaUtils::Album,
                                                DataTypes::TitleRole,
                                                {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
-                                               {i18n("Title"), i18n("Artist"), i18n("Genre"), i18n("Year")},
+                                               {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"), i18nc("@title:menu", "Year")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                                                QUrl{QStringLiteral("image://icon/media-default-album")},
                                                ViewManager::DelegateWithSecondaryText,
-                                               ViewManager::ViewShowRating,
-                                               ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all artists", "Artists")},
+                                               ViewManager::ViewShowRating},
+                                              {{i18nc("@title:window Title of the view of all artists", "Artists")},
                                                QUrl{QStringLiteral("image://icon/view-media-artist")},
                                                ViewManager::GridView,
                                                ViewManager::GenericDataModel,
@@ -76,14 +74,13 @@ public:
                                                ElisaUtils::Artist,
                                                Qt::DisplayRole,
                                                {Qt::DisplayRole},
-                                               {i18n("Name")},
+                                               {i18nc("@title:menu", "Name")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                                QUrl{QStringLiteral("image://icon/view-media-artist")},
                                                ViewManager::DelegateWithoutSecondaryText,
-                                               ViewManager::ViewHideRating,
-                                               ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all tracks", "Tracks")},
+                                               ViewManager::ViewHideRating},
+                                              {{i18nc("@title:window Title of the view of all tracks", "Tracks")},
                                                QUrl{QStringLiteral("image://icon/view-media-track")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
@@ -94,18 +91,17 @@ public:
                                                 DataTypes::GenreRole, DataTypes::YearRole, DataTypes::DurationRole,
                                                 DataTypes::ComposerRole, DataTypes::LyricistRole,
                                                 DataTypes::FileModificationTime},
-                                               {i18n("Title"), i18n("Album"), i18n("Artist"), i18n("Genre"),
-                                                i18n("Year"), i18n("Duration"), i18n("Composer"), i18n("Lyricist"),
-                                                i18n("Last Modified")},
+                                               {i18nc("@title:menu", "Title"), i18nc("@title:menu", "Album"), i18nc("@title:menu", "Artist"), i18nc("@title:menu", "Genre"),
+                                                i18nc("@title:menu", "Year"), i18nc("@title:menu", "Duration"), i18nc("@title:menu", "Composer"), i18nc("@title:menu", "Lyricist"),
+                                                i18nc("@title:menu", "Last Modified")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"),
-                                                i18n("Oldest First"), i18n("Newest First"), i18n("Shortest First"), i18n("Longest First"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"),
-                                                i18n("Oldest First"), i18n("Newest First")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"),
+                                                i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First"), i18nc("@item:inmenu", "Shortest First"), i18nc("@item:inmenu", "Longest First"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"), i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A"),
+                                                i18nc("@item:inmenu", "Oldest First"), i18nc("@item:inmenu", "Newest First")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
-                                               ViewManager::IsTrack,
-                                               ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the view of all genres", "Genres")},
+                                               ViewManager::IsTrack},
+                                              {{i18nc("@title:window Title of the view of all genres", "Genres")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::GridView,
                                                ViewManager::GenericDataModel,
@@ -113,14 +109,13 @@ public:
                                                ElisaUtils::Genre,
                                                Qt::DisplayRole,
                                                {Qt::DisplayRole},
-                                               {i18n("Genre")},
+                                               {i18nc("@title:menu", "Genre")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                                QUrl{QStringLiteral("image://icon/view-media-genre")},
                                                ViewManager::DelegateWithoutSecondaryText,
-                                               ViewManager::ViewHideRating,
-                                               ViewManager::IsFlatModel},
-                                              {{i18nc("Title of the file browser view", "Files")},
+                                               ViewManager::ViewHideRating},
+                                              {{i18nc("@title:window Title of the file browser view", "Files")},
                                                QUrl{QStringLiteral("image://icon/document-open-folder")},
                                                ViewManager::GridView,
                                                ViewManager::FileBrowserModel,
@@ -129,10 +124,9 @@ public:
                                                QUrl{QStringLiteral("image://icon/document-open-folder")},
                                                ViewManager::DelegateWithoutSecondaryText,
                                                ViewManager::ViewHideRating,
-                                               ViewManager::IsFlatModel,
                                                QUrl::fromLocalFile(QDir::rootPath())
                                               },
-                                              {{i18nc("Title of the file radios browser view", "Radio Stations")},
+                                              {{i18nc("@title:window Title of the file radios browser view", "Radio Stations")},
                                                QUrl{QStringLiteral("image://icon/radio")},
                                                ViewManager::ListView,
                                                ViewManager::GenericDataModel,
@@ -140,13 +134,14 @@ public:
                                                ElisaUtils::Radio,
                                                Qt::DisplayRole,
                                                {Qt::DisplayRole},
-                                               {i18n("Name")},
+                                               {i18nc("@title:menu", "Name")},
                                                Qt::AscendingOrder,
-                                               {i18n("A-Z"), i18n("Z-A")},
+                                               {i18nc("@item:inmenu", "A-Z"), i18nc("@item:inmenu", "Z-A")},
                                                ViewManager::MultipleAlbum,
                                                ViewManager::NoDiscHeaders,
-                                               ViewManager::IsRadio,
-                                               ViewManager::IsFlatModel}};
+                                               ViewManager::IsRadio}};
+
+    const int mNumOfBaseViews = mViewsParameters.count();
 
     QMap<ElisaUtils::PlayListEntryType, QUrl> mDefaultIcons = {{ElisaUtils::Album, QUrl{QStringLiteral("image://icon/view-media-album-cover")}},
                                                                {ElisaUtils::Artist, QUrl{QStringLiteral("image://icon/view-media-artist")}},
@@ -154,18 +149,16 @@ public:
 
     ElisaUtils::PlayListEntryType mEmbeddedCategory = ElisaUtils::Unknown;
 
-    ElisaUtils::PlayListEntryType mOldEmbeddedCategory = ElisaUtils::Unknown;
-
     ModelDataLoader *mDataLoader = nullptr;
 
     MusicListenersManager *mManager = nullptr;
 
     DatabaseInterface *mDatabase = nullptr;
-
-    bool mIsFullyInitialized = true;
 };
 
-ViewsListData::ViewsListData(QObject *parent) : QObject(parent), d(std::make_unique<ViewsListDataPrivate>())
+ViewsListData::ViewsListData(QObject *parent)
+    : QObject(parent)
+    , d(std::make_unique<ViewsListDataPrivate>())
 {
     d->mDataLoader = new ModelDataLoader;
     connect(this, &ViewsListData::destroyed, d->mDataLoader, &ModelDataLoader::deleteLater);
@@ -218,30 +211,9 @@ bool ViewsListData::defaultEntry(int index) const
     return d->mEmbeddedCategory == ElisaUtils::Unknown || d->mViewsParameters[index].mEntryType != d->mEmbeddedCategory;
 }
 
-int ViewsListData::indexFromEmbeddedDatabaseId(qulonglong databaseId) const
+ElisaUtils::PlayListEntryType ViewsListData::dataType(int index) const
 {
-    auto result = std::find_if(d->mViewsParameters.begin(), d->mViewsParameters.end(), [this, databaseId](auto data) {
-        return d->mEmbeddedCategory == data.mEntryType && data.mDataFilter.databaseId() == databaseId;
-    });
-
-    if (result == d->mViewsParameters.end()) {
-        return -1;
-    }
-
-    return result - d->mViewsParameters.begin();
-}
-
-int ViewsListData::indexFromEmbeddedName(const QString &name) const
-{
-    auto result = std::find_if(d->mViewsParameters.begin(), d->mViewsParameters.end(), [this, name](auto data) {
-        return d->mEmbeddedCategory == data.mEntryType && data.mMainTitle == name;
-    });
-
-    if (result == d->mViewsParameters.end()) {
-        return -1;
-    }
-
-    return result - d->mViewsParameters.begin();
+    return d->mViewsParameters[index].mDataType;
 }
 
 ElisaUtils::PlayListEntryType ViewsListData::embeddedCategory() const
@@ -251,31 +223,12 @@ ElisaUtils::PlayListEntryType ViewsListData::embeddedCategory() const
 
 void ViewsListData::setEmbeddedCategory(ElisaUtils::PlayListEntryType aEmbeddedView)
 {
-    if (d->mEmbeddedCategory != aEmbeddedView)
-    {
-        d->mOldEmbeddedCategory = d->mEmbeddedCategory;
+    if (d->mEmbeddedCategory != aEmbeddedView) {
         d->mEmbeddedCategory = aEmbeddedView;
 
         Q_EMIT embeddedCategoryChanged();
 
         refreshEmbeddedCategory();
-
-        switch (d->mEmbeddedCategory) {
-        case ElisaUtils::Composer:
-        case ElisaUtils::Container:
-        case ElisaUtils::FileName:
-        case ElisaUtils::Lyricist:
-        case ElisaUtils::Radio:
-        case ElisaUtils::Track:
-        case ElisaUtils::Unknown:
-            d->mIsFullyInitialized = true;
-            Q_EMIT isFullyInitializedChanged();
-            break;
-        case ElisaUtils::Album:
-        case ElisaUtils::Artist:
-        case ElisaUtils::Genre:
-            break;
-        }
     }
 }
 
@@ -304,9 +257,6 @@ void ViewsListData::genresAdded(const DataTypes::ListGenreDataType &newData)
                                        ViewManager::ViewHideRating});
     }
     Q_EMIT dataAdded();
-
-    d->mIsFullyInitialized = true;
-    Q_EMIT isFullyInitializedChanged();
 }
 
 void ViewsListData::artistsAdded(const DataTypes::ListArtistDataType &newData)
@@ -322,7 +272,7 @@ void ViewsListData::artistsAdded(const DataTypes::ListArtistDataType &newData)
     Q_EMIT dataAboutToBeAdded(d->mViewsParameters.size(), d->mViewsParameters.size() + newData.size() - 1);
     for (const auto &oneArtist : newData) {
         d->mViewsParameters.push_back({oneArtist.name(),
-                                       QUrl{QStringLiteral("image://icon/view-media-artist")},
+                                       oneArtist.artistArtURI(),
                                        ViewManager::GridView,
                                        ViewManager::GenericDataModel,
                                        ElisaUtils::FilterByArtist,
@@ -334,9 +284,6 @@ void ViewsListData::artistsAdded(const DataTypes::ListArtistDataType &newData)
                                        ViewManager::ViewShowRating});
     }
     Q_EMIT dataAdded();
-
-    d->mIsFullyInitialized = true;
-    Q_EMIT isFullyInitializedChanged();
 }
 
 void ViewsListData::artistRemoved(qulonglong removedDatabaseId)
@@ -392,9 +339,6 @@ void ViewsListData::albumsAdded(const DataTypes::ListAlbumDataType &newData)
                                        ViewManager::IsTrack});
     }
     Q_EMIT dataAdded();
-
-    d->mIsFullyInitialized = true;
-    Q_EMIT isFullyInitializedChanged();
 }
 
 void ViewsListData::albumRemoved(qulonglong removedDatabaseId)
@@ -439,93 +383,26 @@ void ViewsListData::albumModified(const DataTypes::AlbumDataType &modifiedAlbum)
     }
 }
 
+void ViewsListData::clearEmbeddedItems()
+{
+    if (d->mViewsParameters.count() > d->mNumOfBaseViews) {
+        const int startIndex = d->mNumOfBaseViews;
+        const int numToRemove = d->mViewsParameters.count() - startIndex;
+        Q_EMIT dataAboutToBeRemoved(startIndex, d->mViewsParameters.count() - 1);
+        d->mViewsParameters.remove(startIndex, numToRemove);
+        Q_EMIT dataRemoved();
+    }
+}
+
 void ViewsListData::cleanedDatabase()
 {
     qCDebug(orgKdeElisaViews) << "ViewsListData::cleanedDatabase" << d->mEmbeddedCategory;
-
-    switch (d->mEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-    case ElisaUtils::Genre:
-    case ElisaUtils::Artist:
-        Q_EMIT dataAboutToBeReset();
-        for (int i = 0; i < d->mViewsParameters.size(); ) {
-            if (d->mViewsParameters.at(i).mEntryType == d->mEmbeddedCategory) {
-                d->mViewsParameters.removeAt(i);
-            } else {
-                ++i;
-            }
-        }
-        Q_EMIT dataReset();
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
-        break;
-    }
+    clearEmbeddedItems();
 }
 
 void ViewsListData::refreshEmbeddedCategory()
 {
-    auto elementsCategoryToRemove = ElisaUtils::Unknown;
-
-    switch (d->mOldEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-    case ElisaUtils::Artist:
-    case ElisaUtils::Genre:
-        elementsCategoryToRemove = d->mOldEmbeddedCategory;
-        for (int i = 0; i < d->mViewsParameters.size(); ) {
-            if (d->mViewsParameters.at(i).mEntryType == elementsCategoryToRemove) {
-                Q_EMIT dataAboutToBeRemoved(i, i);
-                d->mViewsParameters.removeAt(i);
-                Q_EMIT dataRemoved();
-            } else {
-                ++i;
-            }
-        }
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
-        break;
-    }
-
-    auto categoryToRemove = ElisaUtils::Unknown;
-
-    switch (d->mEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-    case ElisaUtils::Genre:
-    case ElisaUtils::Artist:
-        categoryToRemove = d->mEmbeddedCategory;
-        for (int i = 0; i < d->mViewsParameters.size(); ) {
-            if (d->mViewsParameters.at(i).mDataType == categoryToRemove) {
-                Q_EMIT dataAboutToBeRemoved(i, i);
-                d->mViewsParameters.removeAt(i);
-                Q_EMIT dataRemoved();
-            } else {
-                ++i;
-            }
-        }
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
-        break;
-    }
+    clearEmbeddedItems();
 
     switch (d->mEmbeddedCategory)
     {
@@ -541,75 +418,7 @@ void ViewsListData::refreshEmbeddedCategory()
     case ElisaUtils::FileName:
     case ElisaUtils::Lyricist:
     case ElisaUtils::Container:
-        break;
-    }
-
-    switch (d->mOldEmbeddedCategory)
-    {
-    case ElisaUtils::Album:
-        Q_EMIT dataAboutToBeAdded(3, 3);
-        d->mViewsParameters.insert(3, {{i18nc("Title of the view of all albums", "Albums")},
-                                       QUrl{QStringLiteral("image://icon/view-media-album-cover")},
-                                       ViewManager::GridView,
-                                       ViewManager::GenericDataModel,
-                                       ElisaUtils::NoFilter,
-                                       ElisaUtils::Album,
-                                       Qt::DisplayRole,
-                                       {DataTypes::TitleRole, DataTypes::ArtistRole, DataTypes::GenreRole, DataTypes::YearRole},
-                                       {i18n("Title"), i18n("Artist"), i18n("Genre"), i18n("Year")},
-                                       Qt::AscendingOrder,
-                                       {i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("A-Z"), i18n("Z-A"), i18n("Oldest First"), i18n("Newest First")},
-                                       QUrl{QStringLiteral("image://icon/media-default-album")},
-                                       ViewManager::DelegateWithSecondaryText,
-                                       ViewManager::ViewShowRating,
-                                       ViewManager::IsFlatModel});
-        Q_EMIT dataAdded();
-        break;
-    case ElisaUtils::Artist:
-        Q_EMIT dataAboutToBeAdded(4, 4);
-        d->mViewsParameters.insert(4, {{i18nc("Title of the view of all artists", "Artists")},
-                                       QUrl{QStringLiteral("image://icon/view-media-artist")},
-                                       ViewManager::GridView,
-                                       ViewManager::GenericDataModel,
-                                       ElisaUtils::NoFilter,
-                                       ElisaUtils::Artist,
-                                       Qt::DisplayRole,
-                                       {Qt::DisplayRole},
-                                       {i18n("Name")},
-                                       Qt::AscendingOrder,
-                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
-                                       QUrl{QStringLiteral("image://icon/view-media-artist")},
-                                       ViewManager::DelegateWithoutSecondaryText,
-                                       ViewManager::ViewHideRating,
-                                       ViewManager::IsFlatModel});
-        Q_EMIT dataAdded();
-        break;
-    case ElisaUtils::Genre:
-        Q_EMIT dataAboutToBeAdded(6, 6);
-        d->mViewsParameters.insert(6, {{i18nc("Title of the view of all genres", "Genres")},
-                                       QUrl{QStringLiteral("image://icon/view-media-genre")},
-                                       ViewManager::GridView,
-                                       ViewManager::GenericDataModel,
-                                       ElisaUtils::NoFilter,
-                                       ElisaUtils::Genre,
-                                       Qt::DisplayRole,
-                                       {Qt::DisplayRole},
-                                       {i18n("Genre")},
-                                       Qt::AscendingOrder,
-                                       {QStringLiteral("A-Z"), QStringLiteral("Z-A")},
-                                       QUrl{QStringLiteral("image://icon/view-media-genre")},
-                                       ViewManager::DelegateWithoutSecondaryText,
-                                       ViewManager::ViewHideRating,
-                                       ViewManager::IsFlatModel});
-        Q_EMIT dataAdded();
-        break;
-    case ElisaUtils::Radio:
-    case ElisaUtils::Track:
-    case ElisaUtils::Unknown:
-    case ElisaUtils::Composer:
-    case ElisaUtils::FileName:
-    case ElisaUtils::Lyricist:
-    case ElisaUtils::Container:
+    case ElisaUtils::PlayList:
         break;
     }
 }
@@ -634,11 +443,6 @@ DatabaseInterface* ViewsListData::database() const
     return d->mDatabase;
 }
 
-bool ViewsListData::isFullyInitialized() const
-{
-    return d->mIsFullyInitialized;
-}
-
 void ViewsListData::setDatabase(DatabaseInterface *aDatabase)
 {
     if (d->mDatabase != aDatabase) {
